var datos = "data/datosDesescolarizacion.csv";
var mapa = "mundo.json";
var paletaColores = ['#32CD32', '#ADFF2F', '#FFFF00', '#FF6347', '#B22222', 'grey'];
var dominio = [2,10,20,30];

const svg = d3.select("svg"),
    width = +svg.attr("width"),
    height = +svg.attr("height")
    
// path del mapa y proyección
const path = d3.geoPath();
const projection = d3.geoNaturalEarth1()
    .scale(150)
    .center([-20,-10]);                            

// crea el Tooltip, cuadro de texto que contiene datos adicionales
const Tooltip = d3.select("body")
    .append("div")
    .style("opacity", 0)
    .attr("class", "tooltip")
    .style("position","absolute")
    .style("background-color", "white")
    .style("border", "solid")
    .style("border-width", "2px")
    .style("border-radius", "5px")
    .style("padding", "5px");

//Zoom
const g = svg.append("g");

const zoom = d3.zoom()
    .scaleExtent([1, 9]) //Límites del zoom
    .on("zoom", function (event) {
        g.attr("transform", event.transform);
    });

svg.call(zoom); //agregar al svg el comportamiento de zoom
        
// Datos y paleta de colores del mapa
const data = new Map();
const colorScale = d3.scaleThreshold()
    .domain(dominio)
    .range(paletaColores);   


Promise.all([
    d3.json(mapa),
    d3.csv(datos, function(d) { // Carga datos del csv
        data.set(d.codigoPais, {
            pais: d.pais,
            total: +d.total,
            mujeres: +d.mujeres,
            hombres: +d.hombres,
            rural: +d.rural,
            urbana: +d.urbana,
            year: d.year,
            fuente: d.fuente
        });
            
    })
]).then(function(loadData){
    let topo = loadData[0]

    //define el evento mouseOver
    let mouseOver = function(d) {
        d3.selectAll(".Country")
        .transition()
        .duration(200)
        .style("opacity", .6)

        d3.select(this)
        .transition()
        .duration(200)
        .style("opacity", 1)

        Tooltip
        .style("opacity", 1)
        d3.select(this)
        .style("stroke", "black")
        .style("opacity", 1)
    }

    //define el evento mousemove
    let mousemove = function(event, d) {
        let countryData = data.get(d.id) || {};
        var contenido = '';
        
        if(countryData.total>=0){ // Crea el texto del Tooltip
            contenido = `<strong>${countryData.pais} </strong>(${countryData.total}%)<br>`;
        
            if(countryData.mujeres || countryData.hombres){
                contenido = contenido + `<strong>Mujeres:</strong> ${countryData.mujeres}%<br> 
                <strong>Hombres:</strong> ${countryData.hombres}% <br>`;
            }
            if(countryData.rural || countryData.urbana){
                contenido = contenido + `<strong>Rural:</strong> ${countryData.rural}% <br>
                <strong>Urbana:</strong> ${countryData.urbana}% <br>`;
            }
            contenido = contenido + `${countryData.fuente}, ${countryData.year}`;
        }else if (!countryData.total && !countryData.mujeres && !countryData.hombres && !countryData.rural && !countryData.urbana) {
            contenido = `<strong>${countryData.pais} <br> </strong>(sin datos)`;
        }

        Tooltip
            .style("opacity", 1)
            .html(contenido)
            .style("left", (event.pageX + 10) + "px")
            .style("top", (event.pageY + 10) + "px");
    }

    //define el evento mouseLeave
    let mouseLeave = function(d) {
        Tooltip
        .style("opacity", 0)
        .html(``)

        d3.select(this)
        .style("stroke", "none")
        
        d3.selectAll(".Country")
        .transition()
        .duration(200)
        .style("opacity", 1)
        .style("stroke","black")

        d3.select(this)
        .transition()
        .duration(200)
    }

    // dibuja el mapa
    g.selectAll("path")
        .data(topo.features)
        .enter()
        .append("path")
        .attr("d", d3.geoPath().projection(projection))//dibuja la silueta de cada país
        //rellena cada país de su correspondiente color
        .attr("fill", function (d) { 
            let countryData = data.get(d.id) || {};
            d.total = countryData.total;
            if (d.total>=0){
                return colorScale(d.total);
            }
            return "grey";
        })

        .style("stroke", "black")
        .style("stroke-width","0.3px")
        .attr("class", function(d){ return "Country" } )
        .style("opacity", 1)
        .on("mouseover", mouseOver )
        .on("mousemove", mousemove )
        .on("mouseleave", mouseLeave )
    }
)


//Leyenda
var keys = ["< 2%", "2% - 10%", "10% - 20%", "20% - 30%", "> 30%", "Sin datos"]

var color = d3.scaleOrdinal()
.domain(keys)
.range(paletaColores);

svg.append("rect").attr("x", 10).attr("y", 270).attr("width", 115).attr("height", 155).style("fill", "white").style("stroke","grey")
svg.append("text").attr("x", 35).attr("y", 290).text('Leyenda').style("font-size", "16px")
// Añade los cuadros de cada color
var size = 15
svg.selectAll("rectangulos")
.data(keys)
.enter()
.append("rect")
    .attr("x", 20)
    .attr("y", function(d,i){ return 300 + i*(size+5)}) 
    .attr("width", size)
    .attr("height", size)
    .style("fill", function(d){ return color(d)})

// Añade texto por cada cuadro de la leyenda
svg.selectAll("etiquetas")
.data(keys)
.enter()
.append("text")
    .attr("x", 22 + size*1.2)
    .attr("y", function(d,i){ return 305 + i*(size+5) + (size/2)}) 
    .text(function(d){ return d})
    .attr("text-anchor", "left")
    .style("alignment-baseline", "middle")